This library uses [python-libusb1](https://github.com/vpelletier/python-libusb1) to communicate with configuration registers, status registers, AXI4-Stream and BRAM ports via AXI4-Stream USB and AXI4-Stream hub modules:

https://pavel-demin.github.io/usb104-a7-notes/usb-interface

This library is mainly used with the applications for the USB104 A7 board:

https://pavel-demin.github.io/usb104-a7-notes
